==> 1.0.0.tar.gz: lib/src/packets-live.dart <==
import 'packets-general.dart'
    show PREFIX, zeros, POSTFIX, START_FILE_NAME_HEX, Packet;

const LIVE_START_PREFIX = '0601000a';
const LIVE_START_POSTFIX = '24';
const LIVE_DATA_PREFIX = '06020005';
const LIVE_END_PREFIX = '03080000';
const LIVE_END_POSTFIX = '0a';

Packet createLiveStartPacket(String channelBytes) {
  final data = PREFIX +
      LIVE_START_PREFIX +
      zeros(2) +
      START_FILE_NAME_HEX +
      zeros(84 - START_FILE_NAME_HEX.length) +
      channelBytes +
      LIVE_START_POSTFIX +
      POSTFIX;
  return Packet(data, false);
}

Packet createLiveDataPacket(String channelBytes, List<int> value) {
  var checkSum = (value[0] + value[1] + value[2] + value[3] + value[4] + 12)
      .toRadixString(16)
      .padLeft(2, '0'); // Get the last 2 chars of the checksum

  checkSum = checkSum.substring(checkSum.length - 2);
  final data = PREFIX +
      LIVE_DATA_PREFIX +
      value[0].toRadixString(16).padLeft(2, '0') +
      value[1].toRadixString(16).padLeft(2, '0') +
      value[2].toRadixString(16).padLeft(2, '0') +
      value[3].toRadixString(16).padLeft(2, '0') +
      value[4].toRadixString(16).padLeft(2, '0') +
      zeros(76) +
      channelBytes +
      checkSum +
      POSTFIX;
  return Packet(data, false);
}

Packet createLiveEndPacket(String channelBytes) {
  final data = PREFIX +
      LIVE_END_PREFIX +
      zeros(86) +
      channelBytes +
      LIVE_END_POSTFIX +
      POSTFIX;
  return Packet(data, true);
}

List<Packet> createLivePackets(String channelBytes, List<List<int>> schedule,
    [smooth = true]) {
  
  final List<Packet> res = [];

  res.add(createLiveStartPacket(channelBytes));

  for (var i = 0; i < schedule.length - 1; i++) {
    if (smooth) {
      const steps = 5;
      final curr = schedule[i];
      final next = schedule[i + 1];
      for (var j = 0; j <= steps; j++) {
        final smooth = List<int>(5);
        for (var k = 0; k < smooth.length; k++) {
          smooth[k] = ((curr[k] * (steps - j) + next[k] * j) / steps).round();
        }
        res.add(createLiveDataPacket(channelBytes, smooth));
      }
    } else {
      res.add(createLiveDataPacket(channelBytes, schedule[i]));
    }
  }
  res.add(createLiveEndPacket(channelBytes));
  return res;
}

==> 1.0.3.tar.gz: lib/src/packets-live.dart <==
import 'packets-general.dart'
    show PREFIX, zeros, POSTFIX, START_FILE_NAME_HEX, Packet;

const LIVE_START_PREFIX = '0601000a';
const LIVE_START_POSTFIX = '24';
const LIVE_DATA_PREFIX = '06020005';
const LIVE_END_PREFIX = '03080000';
const LIVE_END_POSTFIX = '0a';

Packet createLiveStartPacket(String controllerId) {
  final data = PREFIX +
      LIVE_START_PREFIX +
      zeros(2) +
      START_FILE_NAME_HEX +
      zeros(84 - START_FILE_NAME_HEX.length) +
      controllerId +
      LIVE_START_POSTFIX +
      POSTFIX;
  return Packet(data, false);
}

Packet createLiveDataPacket(String controllerId, List<int> value) {
  var checkSum = (value[0] + value[1] + value[2] + value[3] + value[4] + 12)
      .toRadixString(16)
      .padLeft(2, '0'); // Get the last 2 chars of the checksum

  checkSum = checkSum.substring(checkSum.length - 2);
  final data = PREFIX +
      LIVE_DATA_PREFIX +
      value[0].toRadixString(16).padLeft(2, '0') +
      value[1].toRadixString(16).padLeft(2, '0') +
      value[2].toRadixString(16).padLeft(2, '0') +
      value[3].toRadixString(16).padLeft(2, '0') +
      value[4].toRadixString(16).padLeft(2, '0') +
      zeros(76) +
      controllerId +
      checkSum +
      POSTFIX;
  return Packet(data, false);
}

Packet createLiveEndPacket(String controllerId) {
  final data = PREFIX +
      LIVE_END_PREFIX +
      zeros(86) +
      controllerId +
      LIVE_END_POSTFIX +
      POSTFIX;
  return Packet(data, true);
}

List<Packet> createLivePackets(String controllerId, List<List<int>> schedule,
    [smooth = true]) {
  final res = <Packet>[];

  res.add(createLiveStartPacket(controllerId));

  for (var i = 0; i < schedule.length - 1; i++) {
    if (smooth) {
      const steps = 5;
      final curr = schedule[i];
      final next = schedule[i + 1];
      for (var j = 0; j <= steps; j++) {
        final smooth = List<int>(5);
        for (var k = 0; k < smooth.length; k++) {
          smooth[k] = ((curr[k] * (steps - j) + next[k] * j) / steps).round();
        }
        res.add(createLiveDataPacket(controllerId, smooth));
      }
    } else {
      res.add(createLiveDataPacket(controllerId, schedule[i]));
    }
  }
  res.add(createLiveEndPacket(controllerId));
  return res;
}
